==> vue-easy-renderer-1.0.0-4.tgz: package/lib/koa.js <==
// 

const path = require('path');
const rendererFactory = require('./renderer/factory');

const noop = () => { };

function vueEasyRenderer(basePath, VEROptions) {
  const errorHandler = (e) => {
    e.name = `VueEasyRenderer${e.name}`;
    e.type = 'VueEasyRendererError';
    if (VEROptions.onError) {
      VEROptions.onError(e);
    } else {
      console.error(e); // eslint-disable-line no-console
    }
  };
  const readyHandler = VEROptions.onReady || noop;

  const renderer = rendererFactory(basePath, VEROptions);
  renderer.on('error', errorHandler);
  renderer.on('ready', readyHandler);

  return (ctx, next) => {
    const url = ctx.originalUrl;
    ctx.vueRender = (vueFilePath, state, options) => {
      ctx.set('Content-Type', 'text/html');
      const filePath = path.resolve(basePath, vueFilePath);
      const renderOptions = Object.assign({}, { url }, options);

      return renderer.renderToStream(filePath, state, renderOptions).then((result) => {
        ctx.body = result;
      }).catch((e) => {
        errorHandler(e);
        return Promise.reject(e);
      });
    };
    ctx.vueRenderToStream = (vueFilePath, state, options) => {
      const filePath = path.resolve(basePath, vueFilePath);
      const renderOptions = Object.assign({}, { url }, options);
      return renderer.renderToStream(filePath, state, renderOptions);
    };
    ctx.vueRenderToString = (vueFilePath, state, options) => {
      const renderOptions = Object.assign({}, { url }, options);
      const filePath = path.resolve(basePath, vueFilePath);
      return renderer.renderToString(filePath, state, renderOptions);
    };
    return next();
  };
}

module.exports = vueEasyRenderer;

==> vue-easy-renderer-1.0.1.tgz: package/lib/koa.js <==
// 

const path = require('path');
const rendererFactory = require('./renderer/factory');

const noop = () => { };

function vueEasyRenderer(basePath, VEROptions) {
  const errorHandler = (e) => {
    e.name = `VueEasyRenderer${e.name}`;
    e.type = 'VueEasyRendererError';
    if (VEROptions && VEROptions.onError) {
      VEROptions.onError(e);
    } else {
      console.error(e); // eslint-disable-line no-console
    }
  };
  const readyHandler = (VEROptions && VEROptions.onReady) || noop;

  const renderer = rendererFactory(basePath, VEROptions);
  renderer.on('error', errorHandler);
  renderer.on('ready', readyHandler);

  return (ctx, next) => {
    const url = ctx.originalUrl;
    ctx.vueRender = (vueFilePath, state, options) => {
      ctx.set('Content-Type', 'text/html');
      const filePath = path.resolve(basePath, vueFilePath);
      const renderOptions = Object.assign({}, { url }, options);

      return renderer.renderToStream(filePath, state, renderOptions).then((result) => {
        ctx.body = result;
      }).catch((e) => {
        errorHandler(e);
        return Promise.reject(e);
      });
    };
    ctx.vueRenderToStream = (vueFilePath, state, options) => {
      const filePath = path.resolve(basePath, vueFilePath);
      const renderOptions = Object.assign({}, { url }, options);
      return renderer.renderToStream(filePath, state, renderOptions);
    };
    ctx.vueRenderToString = (vueFilePath, state, options) => {
      const renderOptions = Object.assign({}, { url }, options);
      const filePath = path.resolve(basePath, vueFilePath);
      return renderer.renderToString(filePath, state, renderOptions);
    };
    return next();
  };
}

module.exports = vueEasyRenderer;
